"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = NavigationProvider;
var React = _interopRequireWildcard(require("react"));
var _navigation = require("navigation");
var _navigationUtils = require("./navigationUtils");
var _theme = require("./theme");
var _reactNative = require("react-native");
var _navigationReact = require("navigation-react");
var _NavigationStack = _interopRequireDefault(require("./navigation/NavigationStack"));
var _BottomTabsStack = _interopRequireDefault(require("./BottomTabsStack"));
var _RidgeNavigationContext = _interopRequireDefault(require("./contexts/RidgeNavigationContext"));
var _NavigationStackWrapper = _interopRequireDefault(require("./NavigationStackWrapper"));
var _OptimizedContext = require("./contexts/OptimizedContext");
var _historyManager = _interopRequireDefault(require("./navigation/historyManager"));
var _BottomTabBadgeProvider = _interopRequireDefault(require("./contexts/BottomTabBadgeProvider"));
var _BottomTabIndexProvider = _interopRequireDefault(require("./contexts/BottomTabIndexProvider"));
var _HiddenNavbarWithSwipeBack = _interopRequireDefault(require("./HiddenNavbarWithSwipeBack"));
var _BottomTabRefreshProvider = _interopRequireDefault(require("./contexts/BottomTabRefreshProvider"));
var _useNavigationUrl = require("./useNavigationUrl");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function NavigationProvider(_ref) {
  let {
    screens,
    navigationRoot,
    SuspenseContainer,
    themeSettings,
    children,
    initialRootKey,
    basePath
  } = _ref;
  const {
    setGoToUrl,
    goToUrl,
    initialDefaultUrl
  } = (0, _useNavigationUrl.useNavigationUrl)({
    navigationRoot,
    initialRootKey,
    basePath
  });
  const colorScheme = (0, _reactNative.useColorScheme)();
  const theme = React.useMemo(() => (themeSettings || _theme.defaultTheme)[colorScheme || 'light'], [colorScheme, themeSettings]);
  const preloadedCache = React.useRef({});
  const preloadScreen = React.useCallback((screen, params) => {
    try {
      const result = screen.preload(params);
      const path = (0, _navigationUtils.generatePath)(screen.path, params);
      preloadedCache.current[path] = result;
    } catch (error) {
      console.log('[react-native-ridge-navigation] error while preloading screen', screen, params, error);
    }
  }, []);
  const preloadElement = React.useCallback(async screen => {
    try {
      var _screen$element, _screen$element$prelo;
      (_screen$element = screen.element) === null || _screen$element === void 0 ? void 0 : (_screen$element$prelo = _screen$element.preload) === null || _screen$element$prelo === void 0 ? void 0 : _screen$element$prelo.call(_screen$element);
    } catch (error) {
      console.log('[react-native-ridge-navigation] error while preloading element', screen, error);
    }
  }, []);
  const preloadRoot = React.useCallback(rootKey => {
    const root = navigationRoot[rootKey];
    if (!root) {
      console.log('[react-native-ridge-navigation] No root found for key', rootKey);
      return;
    }
    switch (root.type) {
      case 'bottomTabs':
        root.children.forEach(tab => {
          preloadElement(tab.child);
          preloadScreen(tab.child, {});
        });
        break;
      case 'normal':
        if (root.child) {
          preloadElement(root.child);
          preloadScreen(root.child, {});
        }
    }
  }, [navigationRoot, preloadElement, preloadScreen]);
  const rootNavigator = React.useMemo(() => {
    const navigators = Object.entries(navigationRoot).map(_ref2 => {
      let [rootKey, root] = _ref2;
      switch (root.type) {
        case 'bottomTabs':
          // on the web we don't have a nested stack because we want to preserve the history
          // on native, we need to nest the stack for bottom tabs
          return [{
            key: rootKey,
            route: rootKey,
            trackCrumbTrail: false,
            preload: () => preloadRoot(rootKey),
            preloadId: rootKey,
            renderScene: () => _reactNative.Platform.OS === 'web' ? null : /*#__PURE__*/React.createElement(_BottomTabRefreshProvider.default, null, /*#__PURE__*/React.createElement(_BottomTabIndexProvider.default, null, /*#__PURE__*/React.createElement(_BottomTabsStack.default, null)))
          }, ...root.children.map(tab => {
            return screens.map(screen => {
              // we don't want the child path segment in the url
              const isTheSame = tab.child.path === screen.path;
              return {
                key: (0, _navigationUtils.getScreenKey)(rootKey, tab, screen.path),
                route: (0, _navigationUtils.makeVariablesNavigationFriendly)((0, _navigationUtils.getScreenKey)(rootKey, tab, screen.path)),
                renderScene: () => /*#__PURE__*/React.createElement(screen.element, null),
                trackCrumbTrail: !isTheSame,
                screen,
                preloadId: screen.path
              };
            });
          }).flat(2)];
        case 'normal':
          return [{
            key: rootKey,
            route: rootKey,
            trackCrumbTrail: false,
            renderScene: () => /*#__PURE__*/React.createElement(root.child.element, null),
            screen: root.child,
            preload: () => preloadRoot(rootKey),
            preloadId: root.child.path
          }, ...screens.map(screen => ({
            key: (0, _navigationUtils.rootKeyAndPaths)(rootKey, screen.path),
            route: (0, _navigationUtils.makeVariablesNavigationFriendly)((0, _navigationUtils.rootKeyAndPaths)(rootKey, screen.path)),
            renderScene: () => /*#__PURE__*/React.createElement(screen.element, null),
            trackCrumbTrail: true,
            screen,
            preloadId: screen.path
          }))];
      }
    }).flat();
    return new _navigation.StateNavigator(navigators, (0, _historyManager.default)(basePath));
  }, [basePath, navigationRoot, preloadRoot, screens]);
  const preloadLink = React.useCallback(url => {
    var _state$preload;
    const {
      state,
      data,
      crumbs
    } = rootNavigator.parseLink(url);
    state === null || state === void 0 ? void 0 : (_state$preload = state.preload) === null || _state$preload === void 0 ? void 0 : _state$preload.call(state);
    if (state.screen) {
      preloadElement(state.screen);
      preloadScreen(state.screen, data);
    }
    crumbs.forEach(crumb => {
      var _crumb$state, _crumb$state$preload;
      (_crumb$state = crumb.state) === null || _crumb$state === void 0 ? void 0 : (_crumb$state$preload = _crumb$state.preload) === null || _crumb$state$preload === void 0 ? void 0 : _crumb$state$preload.call(_crumb$state);
      if (crumb.state.screen) {
        preloadElement(crumb.state.screen);
        preloadScreen(crumb.state.screen, crumb.data);
      }
    });
  }, [preloadElement, preloadScreen, rootNavigator]);
  const openUrl = React.useCallback((uri, change, fallback) => {
    try {
      const path = (0, _navigationUtils.getPathFromUrl)(uri);
      const rootKey = (0, _navigationUtils.getRootKeyFromPath)(path);
      const root = navigationRoot[rootKey];
      const rootType = root === null || root === void 0 ? void 0 : root.type;
      const isBottomTabs = rootType === 'bottomTabs';
      const isNative = _reactNative.Platform.OS !== 'web';
      if (isNative && isBottomTabs) {
        preloadRoot(rootKey);
        preloadLink(uri);
        rootNavigator.start(rootKey);
      } else {
        preloadLink(uri);
        rootNavigator.navigateLink(uri);
      }
    } catch (e) {
      console.log(`[react-native-ridge-navigation] can't convert deep link to the right stack: ${uri}`, e, {
        fallback,
        change
      });
      if (!fallback && !change) {
        console.debug('[react-native-ridge-navigation] there is no app started yet, lets go to the default url}', {
          defaultUrl: initialDefaultUrl
        });
        // setTimeout(() => {
        openUrl(initialDefaultUrl, false, true);
        // }, 1000);
      }
    }
  },
  // eslint-disable-next-line react-hooks/exhaustive-deps
  []);
  const fluent = React.useCallback(function (fluentParams) {
    var _children;
    let root = navigationRoot[fluentParams.rootKey];
    const tab = fluentParams.tab || (root === null || root === void 0 ? void 0 : (_children = root.children) === null || _children === void 0 ? void 0 : _children[0]);
    let fluentNavigator = new _navigation.StateNavigator(rootNavigator).fluent().navigate(root.type === 'bottomTabs' ? (0, _navigationUtils.getScreenKey)(fluentParams.rootKey, tab) : fluentParams.rootKey);
    for (var _len = arguments.length, fluentScreens = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      fluentScreens[_key - 1] = arguments[_key];
    }
    fluentScreens.forEach(fluentScreen => {
      fluentNavigator = fluentNavigator.navigate(root.type === 'bottomTabs' ? (0, _navigationUtils.getScreenKey)(fluentParams.rootKey, tab, fluentScreen.screen.path) : (0, _navigationUtils.rootKeyAndPaths)(fluentParams.rootKey, fluentScreen.screen.path), fluentScreen.params);
    });
    const url = fluentNavigator.url;
    if (process.env.NODE_ENV === 'development') {
      console.log(`[react-native-ridge-navigation] fluent navigation to ${url}`);
    }
    setGoToUrl(url);
  }, [navigationRoot, rootNavigator, setGoToUrl]);
  const [_, setForceRerender] = React.useState(0);
  const firstTime = React.useRef(true);
  React.useEffect(() => {
    if (goToUrl) {
      if (firstTime.current) {
        openUrl(goToUrl, false);
        firstTime.current = false;
        setForceRerender(prev => prev + 1);
      } else {
        const timerId = setTimeout(() => {
          openUrl(goToUrl, true);
        }, 50);
        return () => {
          clearTimeout(timerId);
        };
      }
    }
    return undefined;
  }, [goToUrl, openUrl]);
  if (firstTime.current) {
    return null;
  }
  return /*#__PURE__*/React.createElement(_RidgeNavigationContext.default.Provider, {
    value: {
      screens,
      rootNavigator,
      navigationRoot,
      preloadedCache: preloadedCache.current,
      preloadRoot,
      preloadScreen,
      theme,
      preloadElement,
      SuspenseContainer,
      fluent,
      goToUrl
    }
  }, /*#__PURE__*/React.createElement(_BottomTabBadgeProvider.default, null, /*#__PURE__*/React.createElement(_navigationReact.NavigationHandler, {
    stateNavigator: rootNavigator
  }, /*#__PURE__*/React.createElement(_NavigationStackWrapper.default, null, children && /*#__PURE__*/React.createElement(_OptimizedContext.OptimizedContextProvider, {
    state: null,
    data: undefined,
    withSuspenseContainer: false
  }, children), /*#__PURE__*/React.createElement(_NavigationStack.default, {
    underlayColor: theme.layout.backgroundColor,
    backgroundColor: () => theme.layout.backgroundColor,
    unmountStyle: () => '',
    renderScene: (state, data) => {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_HiddenNavbarWithSwipeBack.default, null), /*#__PURE__*/React.createElement(_OptimizedContext.OptimizedContextProvider, {
        state: state,
        data: data
      }, /*#__PURE__*/React.createElement(OptimizedRenderScene, {
        renderScene: state.renderScene
      })));
    }
  })))));
}
const OptimizedRenderScene = /*#__PURE__*/React.memo(_ref3 => {
  let {
    renderScene
  } = _ref3;
  return renderScene();
});

// fluent(root.HomeScreen).
// bottomTab(bottomRoots.Post).
// push().
// push().
// push();
//# sourceMappingURL=NavigationProvider.js.map