import useUrl from './useUrl';
import * as React from 'react';
import { getScreenKey } from './navigationUtils';
import { Platform } from 'react-native';
function withoutBasePath(url, basePath) {
  if (!url) {
    return undefined;
  }
  return basePath ? url.replace(`/${basePath}`, '') : url;
}
export function useNavigationUrl(_ref) {
  let {
    navigationRoot,
    initialRootKey,
    basePath
  } = _ref;
  const cachedInitialRootKey = React.useRef(initialRootKey);
  const initialDefaultUrl = React.useMemo(() => {
    const defaultRootKey = cachedInitialRootKey.current || Object.keys(navigationRoot)[0];
    const defaultRoot = navigationRoot[defaultRootKey];
    return '/' + getPathFromRoot(defaultRoot, undefined, defaultRootKey);
  }, [navigationRoot]);
  const initialUrl = useUrl() || initialDefaultUrl;
  const [goToUrl, setGoToUrl] = React.useState(initialUrl);
  React.useEffect(() => {
    setGoToUrl(initialUrl);
  }, [initialUrl]);
  React.useEffect(() => {
    if (goToUrl) {
      // reset goToUrl after it has been handled, so we can handle new deep links
      // because in the meantime user can navigate away from goToUrl
      const timerId = setTimeout(() => {
        setGoToUrl(undefined);
      }, 1500);
      return () => {
        clearTimeout(timerId);
      };
    }
    return undefined;
  }, [goToUrl, setGoToUrl]);
  return {
    goToUrl: withoutBasePath(goToUrl, basePath),
    setGoToUrl,
    initialDefaultUrl: withoutBasePath(initialDefaultUrl, basePath)
  };
}
function getPathFromRoot(root, tab, rootKey) {
  if (root.type === 'bottomTabs') {
    return getScreenKey(rootKey, tab || root.children[0], Platform.OS === 'web' ? root.children[0].path : undefined);
  }
  return getScreenKey(rootKey, undefined, root.child.path);
}
//# sourceMappingURL=useNavigationUrl.js.map